@@ -1,6 +1,8 @@
 from fastapi_camelcase import CamelModel
 import math
 
+from pydantic import Field
+
 
 class PageMetaDto(CamelModel):
     def __init__(self, page: int, limit: int, item_count: int):
@@ -14,7 +16,7 @@ class PageMetaDto(CamelModel):
             has_next_page=page < page_count,
         )
 
-    page: int
+    page: int = Field(..., ge=1)
     page_size: int
     item_count: int
     page_count: int
